@@ -16,18 +16,19 @@ def on_get(req, resp, key):
     information.  Key can be requested at /api/v0/ical_key.
 
     """
+    roles = req.get_param_as_list('roles')
+
     name_and_type = get_name_and_type_from_key(key)
     if name_and_type is None:
         raise HTTPNotFound()
 
     name, type = name_and_type
     start = int(time.time())
+    events = []
     if type == 'user':
-        events = get_user_events(name, start)
+        events = get_user_events(name, start, roles=roles)
     elif type == 'team':
-        events = get_team_events(name, start, include_subscribed=True)
-    else:                       # should not happen
-        events = []
+        events = get_team_events(name, start, roles=roles, include_subscribed=True)
 
     resp.body = ical.events_to_ical(events, name, contact=False)
     resp.set_header('Content-Type', 'text/calendar')
