@@ -73,7 +73,7 @@ def init_falcon_api(config):
     ]
     if config.get('require_auth'):
         middlewares.append(AuthMiddleware())
-    application = falcon.App(middleware=middlewares, cors_enable=True)
+    application = falcon.App(middleware=middlewares)
     application.req_options.auto_parse_form_urlencoded = False
     application.set_error_serializer(json_error_serializer)
     application.req_options.strip_url_path_trailing_slash = True
