@@ -6,7 +6,6 @@ import time
 import hmac
 import hashlib
 import base64
-from streql import equals
 import importlib
 from falcon import HTTPUnauthorized, HTTPForbidden, Request
 from .. import db
@@ -131,7 +130,7 @@ def is_client_digest_valid(client_digest, api_key, window, method, path, body):
     text = '%s %s %s %s' % (window, method, path, body)
     HMAC = hmac.new(api_key, text.encode('utf-8'), hashlib.sha512)
     digest = base64.urlsafe_b64encode(HMAC.digest())
-    if equals(client_digest, digest):
+    if hmac.compare_digest(bytes(client_digest, 'utf-8'), digest):
         return True
     return False
 
